# Changelog

## [0.2.1](https://github.com/cademirch/snkmt/compare/v0.2.0...v0.2.1) (2025-09-20)


### Bug Fixes

* use dev branch of logger plugin ([#18](https://github.com/cademirch/snkmt/issues/18)) ([d320f51](https://github.com/cademirch/snkmt/commit/d320f51d514733eb6b1c3b27aea56f7ad663fd6e))

## [0.2.0](https://github.com/cademirch/snkmt/compare/v0.1.2...v0.2.0) (2025-09-20)


### Features

* refactoring; workflow filtering; support multiple databases ([#15](https://github.com/cademirch/snkmt/issues/15)) ([72f3528](https://github.com/cademirch/snkmt/commit/72f35285995cf8ab1c23f59aca8821f7de5e42fe))

## [0.1.2](https://github.com/cademirch/snkmt/compare/v0.1.1...v0.1.2) (2025-08-30)


### Bug Fixes

* remove db logfile ([#8](https://github.com/cademirch/snkmt/issues/8)) ([565fbf7](https://github.com/cademirch/snkmt/commit/565fbf703a7689fd2ebafa597049c6d842a90510))

## [0.1.1](https://github.com/cademirch/snkmt/compare/v0.1.0...v0.1.1) (2025-06-10)


### Bug Fixes

* lower min python version ([3f8c6f8](https://github.com/cademirch/snkmt/commit/3f8c6f826c05bb902ec8eee5a53ee29327b7c650))


### Documentation

* add readme and screenshots ([d45e3fc](https://github.com/cademirch/snkmt/commit/d45e3fc71e4eb727182b8a98ddc881f045650b1a))

## 0.1.0 (2025-06-03)


### Features

* add basic db cli commands ([5dc805b](https://github.com/cademirch/snkmt/commit/5dc805b19b85627aeb52f61fb858332140fa111d))


### Bug Fixes

* dont run migrations if creating new db ([9cd7642](https://github.com/cademirch/snkmt/commit/9cd76423c368c4ad252b45b09b14e98d037a36d0))


### Dependencies

* fix dev dep ([a2ab7a4](https://github.com/cademirch/snkmt/commit/a2ab7a4ef964218261e20471f93b690d36bc868d))
